@@ -26,13 +26,18 @@ class Pop3(HandlerBase):
     max_tries = 10
     cmds = {}
 
-    def __init__(self, sessions, options, workdir):
-        super(Pop3, self).__init__(sessions, options, workdir)
+    def __init__(self, options, workdir):
+        super(Pop3, self).__init__(options, workdir)
         Pop3.max_tries = int(self.options['protocol_specific_data']['max_attempts'])
 
     def handle_session(self, gsocket, address):
         session = self.create_session(address)
+        try:
+            self._handle_session(session, gsocket, address)
+        finally:
+            self.close_session(session)
 
+    def _handle_session(self, session, gsocket, address):
         session.vdata['MAILSPOOL'] = {}
         session.vdata['deleted_index'] = []
 
@@ -45,7 +50,7 @@ class Pop3(HandlerBase):
             try:
                 raw_msg = fileobj.readline()
             except socket.error:
-                session.connected = False
+                session.end_session()
                 break
 
             session.activity()
@@ -71,7 +76,7 @@ class Pop3(HandlerBase):
                 if state == 'AUTHORIZATION' or cmd == 'quit':
                     state = return_value
 
-        session.connected = False
+        session.end_session()
 
     # APOP mrose c4c9334bac560ecc979e58001b3e22fb
     # +OK mrose's maildrop has 2 messages (320 octets)
@@ -216,11 +221,11 @@ class Pop3(HandlerBase):
             session.transcript_outgoing(msg + '\n')
             gsocket.sendall(msg + "\n")
         except socket.error, (value, msg):
-            session.connected = False
+            session.end_session()
 
     def send_data(self, session, gsocket, data):
         try:
             gsocket.sendall(data)
         except socket.error, (value, msg):
-            session.connected = False
+            session.end_session()
 
